@@ -2,10 +2,12 @@ use strict;
 use warnings;
 package App::Prefix;
 
-our $VERSION = '0.06';  # version also mentioned in POD below, if it exists
+our $VERSION = '0.08'; 
 
 # ABSTRACT: provides 'prefix' filter, which prepends data to lines passed
 #
-# Copyright 2010-2013 Josh Rabinowitz.
-
-1;
+# NOTE: main file for this distribution is bin/prefix
+# 
+#  Copyright 2010-2013 Josh Rabinowitz.
+#
+# 1;
